pub struct WindowsObjectHeaderNameInfo<'a, Driver>{ /* private fields */ }Expand description
A name information for a Windows object.
This structure stores the name and directory information associated with a named kernel object.
Implementation Details
Corresponds to _OBJECT_HEADER_NAME_INFO.
Implementations
Sourceimpl<'a, Driver> WindowsObjectHeaderNameInfo<'a, Driver>
impl<'a, Driver> WindowsObjectHeaderNameInfo<'a, Driver>
Sourcepub fn new(vmi: VmiState<'a, WindowsOs<Driver>>, va: Va) -> Self
pub fn new(vmi: VmiState<'a, WindowsOs<Driver>>, va: Va) -> Self
Creates a new Windows object header name info.
Sourcepub fn directory(&self) -> Result<Option<WindowsObject<'a, Driver>>, VmiError>
pub fn directory(&self) -> Result<Option<WindowsObject<'a, Driver>>, VmiError>
Returns the directory object associated with the object name.
Implementation Details
Corresponds to _OBJECT_HEADER_NAME_INFO.Directory.