pub struct WindowsPeb<'a, Driver>{ /* private fields */ }Expand description
PEB accessor with a runtime pointer width.
The PEB is a user-mode structure that stores process-wide information, such as loaded modules, heap data, and environment settings.
Implementation Details
Corresponds to _PEB.
Implementations
Sourceimpl<'a, Driver> WindowsPeb<'a, Driver>
impl<'a, Driver> WindowsPeb<'a, Driver>
Sourcepub fn with_kind(
vmi: VmiState<'a, WindowsOs<Driver>>,
va: Va,
root: Pa,
kind: WindowsWow64Kind,
) -> Self
pub fn with_kind( vmi: VmiState<'a, WindowsOs<Driver>>, va: Va, root: Pa, kind: WindowsWow64Kind, ) -> Self
Creates a new PEB accessor with an explicit address space root and pointer width.
Sourcepub fn ldr(&self) -> Result<WindowsPebLdrData<'a, Driver>, VmiError>
pub fn ldr(&self) -> Result<WindowsPebLdrData<'a, Driver>, VmiError>
Returns the PEB loader data.
The loader data contains the three module lists maintained by the Windows loader.
Implementation Details
Corresponds to _PEB.Ldr.
Sourcepub fn process_parameters(
&self,
) -> Result<WindowsProcessParameters<'a, Driver>, VmiError>
pub fn process_parameters( &self, ) -> Result<WindowsProcessParameters<'a, Driver>, VmiError>
Returns the process parameters of the process.
Implementation Details
Corresponds to _PEB.ProcessParameters.
Sourcepub fn current_directory(&self) -> Result<String, VmiError>
pub fn current_directory(&self) -> Result<String, VmiError>
Returns the current directory.
Shortcut for self.process_parameters()?.current_directory().
Sourcepub fn dll_path(&self) -> Result<String, VmiError>
pub fn dll_path(&self) -> Result<String, VmiError>
Returns the DLL search path.
Shortcut for self.process_parameters()?.dll_path().
Sourcepub fn image_path_name(&self) -> Result<String, VmiError>
pub fn image_path_name(&self) -> Result<String, VmiError>
Returns the full path of the executable image.
Shortcut for self.process_parameters()?.image_path_name().
Sourcepub fn command_line(&self) -> Result<String, VmiError>
pub fn command_line(&self) -> Result<String, VmiError>
Returns the command line used to launch the process.
Shortcut for self.process_parameters()?.command_line().