pub struct WindowsPebLdrData<'a, Driver>{ /* private fields */ }Expand description
PEB loader data accessor with a runtime pointer width.
Implementation Details
Corresponds to _PEB_LDR_DATA.
Implementations
Sourceimpl<'a, Driver> WindowsPebLdrData<'a, Driver>
impl<'a, Driver> WindowsPebLdrData<'a, Driver>
Sourcepub fn new(vmi: VmiState<'a, WindowsOs<Driver>>, va: Va) -> Self
pub fn new(vmi: VmiState<'a, WindowsOs<Driver>>, va: Va) -> Self
Creates a new PEB loader data accessor.
Sourcepub fn with_kind(
vmi: VmiState<'a, WindowsOs<Driver>>,
va: Va,
root: Pa,
kind: WindowsWow64Kind,
) -> Self
pub fn with_kind( vmi: VmiState<'a, WindowsOs<Driver>>, va: Va, root: Pa, kind: WindowsWow64Kind, ) -> Self
Creates a new PEB loader data accessor with an explicit address space root and pointer width.
Sourcepub fn in_load_order_modules(
&self,
) -> Result<impl Iterator<Item = Result<WindowsUserModule<'a, Driver>, VmiError>> + use<'a, Driver>, VmiError>
pub fn in_load_order_modules( &self, ) -> Result<impl Iterator<Item = Result<WindowsUserModule<'a, Driver>, VmiError>> + use<'a, Driver>, VmiError>
Returns an iterator over modules in load order.
Implementation Details
Corresponds to _PEB_LDR_DATA.InLoadOrderModuleList.
Sourcepub fn in_memory_order_modules(
&self,
) -> Result<impl Iterator<Item = Result<WindowsUserModule<'a, Driver>, VmiError>> + use<'a, Driver>, VmiError>
pub fn in_memory_order_modules( &self, ) -> Result<impl Iterator<Item = Result<WindowsUserModule<'a, Driver>, VmiError>> + use<'a, Driver>, VmiError>
Returns an iterator over modules in memory order.
Implementation Details
Corresponds to _PEB_LDR_DATA.InMemoryOrderModuleList.
Sourcepub fn in_initialization_order_modules(
&self,
) -> Result<impl Iterator<Item = Result<WindowsUserModule<'a, Driver>, VmiError>> + use<'a, Driver>, VmiError>
pub fn in_initialization_order_modules( &self, ) -> Result<impl Iterator<Item = Result<WindowsUserModule<'a, Driver>, VmiError>> + use<'a, Driver>, VmiError>
Returns an iterator over modules in initialization order.
Implementation Details
Corresponds to _PEB_LDR_DATA.InInitializationOrderModuleList.