pub struct WindowsTeb<'a, Driver>{ /* private fields */ }Expand description
TEB accessor with a runtime pointer width.
The TEB is a user-mode structure that stores thread-specific information, such as the last error value and thread-local storage.
Implementation Details
Corresponds to _TEB.
Implementations
Sourceimpl<'a, Driver> WindowsTeb<'a, Driver>
impl<'a, Driver> WindowsTeb<'a, Driver>
Sourcepub fn with_kind(
vmi: VmiState<'a, WindowsOs<Driver>>,
va: Va,
root: Pa,
kind: WindowsWow64Kind,
) -> Self
pub fn with_kind( vmi: VmiState<'a, WindowsOs<Driver>>, va: Va, root: Pa, kind: WindowsWow64Kind, ) -> Self
Creates a new TEB accessor with an explicit address space root and pointer width.
Sourcepub fn peb(&self) -> Result<Option<WindowsPeb<'a, Driver>>, VmiError>
pub fn peb(&self) -> Result<Option<WindowsPeb<'a, Driver>>, VmiError>
Returns the process environment block (PEB) associated with the thread.
Implementation Details
Corresponds to _TEB.ProcessEnvironmentBlock.
Sourcepub fn last_error_value(&self) -> Result<u32, VmiError>
pub fn last_error_value(&self) -> Result<u32, VmiError>
Returns the last error value for the thread.
The equivalent of GetLastError() in the Windows API.
Implementation Details
Corresponds to _TEB.LastErrorValue.
Sourcepub fn last_status_value(&self) -> Result<u32, VmiError>
pub fn last_status_value(&self) -> Result<u32, VmiError>
Returns the last status value for the current thread.
LastStatusValue is an NTSTATUS value, whereas LastError is a
Win32 error code. You can obtain the Win32 error code by calling
last_error_value.
Implementation Details
Corresponds to _TEB.LastStatusValue.