pub struct WindowsTokenFlags(/* private fields */);Expand description
Flags stored in _TOKEN.TokenFlags.
Implementations
Sourceimpl WindowsTokenFlags
impl WindowsTokenFlags
Sourcepub const HAS_TRAVERSE_PRIVILEGE: Self
pub const HAS_TRAVERSE_PRIVILEGE: Self
Corresponds to TOKEN_HAS_TRAVERSE_PRIVILEGE.
Sourcepub const HAS_BACKUP_PRIVILEGE: Self
pub const HAS_BACKUP_PRIVILEGE: Self
Corresponds to TOKEN_HAS_BACKUP_PRIVILEGE.
Sourcepub const HAS_RESTORE_PRIVILEGE: Self
pub const HAS_RESTORE_PRIVILEGE: Self
Corresponds to TOKEN_HAS_RESTORE_PRIVILEGE.
Sourcepub const WRITE_RESTRICTED: Self
pub const WRITE_RESTRICTED: Self
Corresponds to TOKEN_WRITE_RESTRICTED.
Sourcepub const IS_RESTRICTED: Self
pub const IS_RESTRICTED: Self
Corresponds to TOKEN_IS_RESTRICTED.
Sourcepub const SESSION_NOT_REFERENCED: Self
pub const SESSION_NOT_REFERENCED: Self
Corresponds to TOKEN_SESSION_NOT_REFERENCED.
Sourcepub const SANDBOX_INERT: Self
pub const SANDBOX_INERT: Self
Corresponds to TOKEN_SANDBOX_INERT.
Sourcepub const HAS_IMPERSONATE_PRIVILEGE: Self
pub const HAS_IMPERSONATE_PRIVILEGE: Self
Corresponds to TOKEN_HAS_IMPERSONATE_PRIVILEGE.
Sourcepub const SE_BACKUP_PRIVILEGES_CHECKED: Self
pub const SE_BACKUP_PRIVILEGES_CHECKED: Self
Corresponds to SE_BACKUP_PRIVILEGES_CHECKED.
Sourcepub const VIRTUALIZE_ALLOWED: Self
pub const VIRTUALIZE_ALLOWED: Self
Corresponds to TOKEN_VIRTUALIZE_ALLOWED.
Sourcepub const VIRTUALIZE_ENABLED: Self
pub const VIRTUALIZE_ENABLED: Self
Corresponds to TOKEN_VIRTUALIZE_ENABLED.
Sourcepub const IS_FILTERED: Self
pub const IS_FILTERED: Self
Corresponds to TOKEN_IS_FILTERED.
Sourcepub const HAS_OWN_CLAIM_ATTRIBUTES: Self
pub const HAS_OWN_CLAIM_ATTRIBUTES: Self
Corresponds to TOKEN_HAS_OWN_CLAIM_ATTRIBUTES.
Sourcepub const PRIVATE_NAMESPACE: Self
pub const PRIVATE_NAMESPACE: Self
Corresponds to TOKEN_PRIVATE_NAMESPACE.
Sourcepub const DO_NOT_USE_GLOBAL_ATTRIBS_FOR_QUERY: Self
pub const DO_NOT_USE_GLOBAL_ATTRIBS_FOR_QUERY: Self
Corresponds to TOKEN_DO_NOT_USE_GLOBAL_ATTRIBS_FOR_QUERY.
Sourcepub const SPECIAL_ENCRYPTED_OPEN: Self
pub const SPECIAL_ENCRYPTED_OPEN: Self
Corresponds to SPECIAL_ENCRYPTED_OPEN.
Sourcepub const NO_CHILD_PROCESS: Self
pub const NO_CHILD_PROCESS: Self
Corresponds to TOKEN_NO_CHILD_PROCESS.
Sourcepub const NO_CHILD_PROCESS_UNLESS_SECURE: Self
pub const NO_CHILD_PROCESS_UNLESS_SECURE: Self
Corresponds to TOKEN_NO_CHILD_PROCESS_UNLESS_SECURE.
Sourcepub const AUDIT_NO_CHILD_PROCESS: Self
pub const AUDIT_NO_CHILD_PROCESS: Self
Corresponds to TOKEN_AUDIT_NO_CHILD_PROCESS.
Sourcepub const ENFORCE_REDIRECTION_TRUST: Self
pub const ENFORCE_REDIRECTION_TRUST: Self
Corresponds to TOKEN_ENFORCE_REDIRECTION_TRUST.
Sourcepub const AUDIT_REDIRECTION_TRUST: Self
pub const AUDIT_REDIRECTION_TRUST: Self
Corresponds to TOKEN_AUDIT_REDIRECTION_TRUST.
Sourcepub const LEARNING_MODE_LOGGING: Self
pub const LEARNING_MODE_LOGGING: Self
Corresponds to TOKEN_LEARNING_MODE_LOGGING.
Sourcepub const PERMISSIVE_LEARNING_MODE: Self
pub const PERMISSIVE_LEARNING_MODE: Self
Corresponds to TOKEN_PERMISSIVE_LEARNING_MODE.
Implies LEARNING_MODE_LOGGING.
Sourcepub const SYSTEM_MANAGED_ADMIN_FULL_TOKEN: Self
pub const SYSTEM_MANAGED_ADMIN_FULL_TOKEN: Self
Corresponds to TOKEN_SYSTEM_MANAGED_ADMIN_FULL_TOKEN.
Sourceimpl WindowsTokenFlags
impl WindowsTokenFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl WindowsTokenFlags
impl WindowsTokenFlags
Sourcepub const fn iter(&self) -> Iter<WindowsTokenFlags>
pub const fn iter(&self) -> Iter<WindowsTokenFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WindowsTokenFlags>
pub const fn iter_names(&self) -> IterNames<WindowsTokenFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.