WindowsTrapFrame

Struct WindowsTrapFrame 

pub struct WindowsTrapFrame<'a, Driver>
where Driver: VmiRead, Driver::Architecture: ArchAdapter<Driver>,
{ /* private fields */ }
A Windows trap frame.

A trap frame is a kernel structure that contains the context of a thread when it is interrupted by an exception or an interrupt. It is used to save the state of the thread so that it can be resumed later.

Implementation Details

Corresponds to _KTRAP_FRAME.

Implementations

Source

impl<'a, Driver> WindowsTrapFrame<'a, Driver>
where Driver: VmiRead, Driver::Architecture: ArchAdapter<Driver>,

pub fn new(vmi: VmiState<'a, WindowsOs<Driver>>, va: Va) -> Self

Creates a new Windows trap frame.

pub fn instruction_pointer(&self) -> Result<Va, VmiError>

Returns the instruction pointer.

Implementation Details

Corresponds to _KTRAP_FRAME.Rip.

pub fn stack_pointer(&self) -> Result<Va, VmiError>

Returns the stack pointer.

Implementation Details

Corresponds to _KTRAP_FRAME.Rsp.