pub struct WindowsProcess<'a, Driver>{ /* private fields */ }Expand description
A Windows process.
A process in Windows is represented by the _EPROCESS structure,
which contains metadata about its execution state, memory layout,
and handles.
Implementation Details
Corresponds to _EPROCESS.
Implementations
Sourceimpl<'a, Driver> WindowsProcess<'a, Driver>
impl<'a, Driver> WindowsProcess<'a, Driver>
Sourcepub fn new(vmi: VmiState<'a, WindowsOs<Driver>>, process: ProcessObject) -> Self
pub fn new(vmi: VmiState<'a, WindowsOs<Driver>>, process: ProcessObject) -> Self
Creates a new Windows process.
Sourcepub fn is_wow64(&self) -> Result<bool, VmiError>
pub fn is_wow64(&self) -> Result<bool, VmiError>
Checks if the process is a WoW64 process.
Implementation Details
Corresponds to _EPROCESS.WoW64Process != NULL.
Sourcepub fn peb(&self) -> Result<Option<WindowsPeb<'a, Driver>>, VmiError>
pub fn peb(&self) -> Result<Option<WindowsPeb<'a, Driver>>, VmiError>
Returns the process environment block (PEB).
Implementation Details
The function first reads the _EPROCESS.WoW64Process field to determine
if the process is a 32-bit process. If the field is NULL, the process
is 64-bit. Otherwise, the function reads the _EWOW64PROCESS.Peb field
to get the 32-bit PEB.
Sourcepub fn native_peb(&self) -> Result<Option<WindowsPeb<'a, Driver>>, VmiError>
pub fn native_peb(&self) -> Result<Option<WindowsPeb<'a, Driver>>, VmiError>
Returns the native process environment block (PEB).
Implementation Details
Corresponds to _EPROCESS.Peb.
Sourcepub fn session(&self) -> Result<Option<WindowsSession<'a, Driver>>, VmiError>
pub fn session(&self) -> Result<Option<WindowsSession<'a, Driver>>, VmiError>
Returns the session of the process.
Sourcepub fn handle_table(
&self,
) -> Result<Option<WindowsHandleTable<'a, Driver>>, VmiError>
pub fn handle_table( &self, ) -> Result<Option<WindowsHandleTable<'a, Driver>>, VmiError>
Returns the handle table of the process.
Implementation Details
Corresponds to _EPROCESS.ObjectTable.
Sourcepub fn lookup_object<T>(&self, handle: u64) -> Result<Option<T>, VmiError>where
T: FromWindowsObject<'a, Driver>,
pub fn lookup_object<T>(&self, handle: u64) -> Result<Option<T>, VmiError>where
T: FromWindowsObject<'a, Driver>,
Looks up the object associated with the given handle and attempts to convert it to the specified type.
Resolves a handle value through the process handle table
and converts the resulting WindowsObject using the
FromWindowsObject trait.
Returns Ok(None) if the handle table is unavailable,
the handle is invalid, the entry has no associated object,
or the object is not of the requested type.
Examples
// Look up the raw object.
let object = process.lookup_object::<WindowsObject<_>>(handle)?;
// Look up and convert to a specific type.
let process = current_process.lookup_object::<WindowsProcess<_>>(handle)?;
let file = current_process.lookup_object::<WindowsFileObject<_>>(handle)?;Sourcepub fn vad_root(&self) -> Result<Option<WindowsRegion<'a, Driver>>, VmiError>
pub fn vad_root(&self) -> Result<Option<WindowsRegion<'a, Driver>>, VmiError>
Returns the root of the virtual address descriptor (VAD) tree.
Implementation Details
Corresponds to _EPROCESS.VadRoot->BalancedRoot for Windows 7 and
_EPROCESS.VadRoot->Root for Windows 8.1 and later.
Sourcepub fn vad_hint(&self) -> Result<Option<WindowsRegion<'a, Driver>>, VmiError>
pub fn vad_hint(&self) -> Result<Option<WindowsRegion<'a, Driver>>, VmiError>
Returns the VAD hint node.
The VAD hint is an optimization used by Windows to speed up VAD lookups. This method returns the address of the hint node in the VAD tree.
Implementation Details
Corresponds to _EPROCESS.VadRoot->NodeHint for Windows 7 and
_EPROCESS.VadRoot->Hint for Windows 8.1 and later.