pub struct WindowsProcessParameters<'a, Driver>{ /* private fields */ }Expand description
Process parameters accessor with a runtime pointer width.
Contains command-line arguments, environment variables, and other startup information for a process.
Implementation Details
Corresponds to _RTL_USER_PROCESS_PARAMETERS.
Implementations
Sourceimpl<'a, Driver> WindowsProcessParameters<'a, Driver>
impl<'a, Driver> WindowsProcessParameters<'a, Driver>
Sourcepub fn new(vmi: VmiState<'a, WindowsOs<Driver>>, va: Va) -> Self
pub fn new(vmi: VmiState<'a, WindowsOs<Driver>>, va: Va) -> Self
Creates a new process parameters accessor.
Sourcepub fn with_kind(
vmi: VmiState<'a, WindowsOs<Driver>>,
va: Va,
root: Pa,
kind: WindowsWow64Kind,
) -> Self
pub fn with_kind( vmi: VmiState<'a, WindowsOs<Driver>>, va: Va, root: Pa, kind: WindowsWow64Kind, ) -> Self
Creates a new process parameters accessor with an explicit address space root and pointer width.
Sourcepub fn current_directory(&self) -> Result<String, VmiError>
pub fn current_directory(&self) -> Result<String, VmiError>
Returns the current directory.
Implementation Details
Corresponds to _RTL_USER_PROCESS_PARAMETERS.CurrentDirectory.DosPath.
Sourcepub fn dll_path(&self) -> Result<String, VmiError>
pub fn dll_path(&self) -> Result<String, VmiError>
Returns the DLL search path.
Implementation Details
Corresponds to _RTL_USER_PROCESS_PARAMETERS.DllPath.