pub struct WindowsTrapFrame<'a, Driver>{ /* private fields */ }Expand description
A Windows trap frame.
A trap frame is a kernel structure that contains the context of a thread when it is interrupted by an exception or an interrupt. It is used to save the state of the thread so that it can be resumed later.
Implementation Details
Corresponds to _KTRAP_FRAME.
Implementations